@@ -7,6 +7,7 @@
 #include <Rinternals.h>
 #include <R_ext/Rdynload.h>
 #include <stdbool.h>
+#include <stdint.h> // uint64_t
 
 // Definitions --------------------------------------------------
 
@@ -20,6 +21,7 @@
   #define LOGICAL_RO(x) ((const int*) LOGICAL(x))
   #define INTEGER_RO(x) ((const int*) INTEGER(x))
   #define REAL_RO(x) ((const double*) REAL(x))
+  #define RAW_RO(x) ((const Rbyte*) RAW(x))
   #define STRING_PTR_RO(x) ((const SEXP*) STRING_PTR(x))
 #endif
 
